@@ -190,9 +190,7 @@ public:
       @param str The string to print inside the box
       @param flags is a bitwise OR of Qt::AlignmentFlags and Qt::TextFlags values.
     */
-    void showEventBox(QPainter &p, int linewidth, const QRect &box,
-                      const KCalendarCore::Incidence::Ptr &incidence, const QString &str,
-                      int flags = -1);
+    void showEventBox(QPainter &p, int linewidth, const QRect &box, const KCalendarCore::Incidence::Ptr &incidence, const QString &str, int flags = -1);
 
     /**
       Draw a subheader box with a shaded background and the given string
@@ -210,8 +208,7 @@ public:
       @param str ext to be printed inside the box
       @param flags is a bitwise OR of Qt::AlignmentFlags and Qt::TextFlags values.
     */
-    void drawVerticalBox(QPainter &p, int linewidth, const QRect &box, const QString &str,
-                         int flags = -1);
+    void drawVerticalBox(QPainter &p, int linewidth, const QRect &box, const QString &str, int flags = -1);
 
     /**
       Draw a component box with a heading (printed in bold).
@@ -234,10 +231,7 @@ public:
               the contents, use the return value as the top-value of your
               custom contents in that case.
     */
-    int drawBoxWithCaption(QPainter &p, const QRect &box, const QString &caption,
-                           const QString &contents, bool sameLine, bool expand,
-                           const QFont &captionFont, const QFont &textFont,
-                           bool richContents = false);
+    int drawBoxWithCaption(QPainter &p, const QRect &box, const QString &caption, const QString &contents, bool sameLine, bool expand, const QFont &captionFont, const QFont &textFont, bool richContents = false);
 
     /**
       Draw the gray header bar of the printout to the QPainter.
@@ -267,8 +261,7 @@ public:
               is box.bottom, otherwise it is larger than box.bottom
               and matches the y-coordinate of the surrounding rectangle.
     */
-    int drawHeader(QPainter &p, const QString &title, const QDate &month1, const QDate &month2,
-                   const QRect &box, bool expand = false, QColor backColor = QColor());
+    int drawHeader(QPainter &p, const QString &title, const QDate &month1, const QDate &month2, const QRect &box, bool expand = false, QColor backColor = QColor());
 
     /**
       Draw a page footer containing the printing date and possibly
@@ -339,9 +332,7 @@ public:
       @param excludePrivate Whether to exclude Incidence marked private.
       @return The height used for the all-day box.
     */
-    int drawAllDayBox(QPainter &p, const KCalendarCore::Event::List &eventList, const QDate &qd,
-                      bool expandable, const QRect &box, bool excludeConfidential,
-                      bool excludePrivate);
+    int drawAllDayBox(QPainter &p, const KCalendarCore::Event::List &eventList, const QDate &qd, bool expandable, const QRect &box, bool excludeConfidential, bool excludePrivate);
     /**
       Draw the agenda box for the day print style (the box showing all events of that day).
       Also draws a grid with half-hour spacing of the grid lines.
@@ -368,15 +359,9 @@ public:
       @param excludePrivate Whether to exclude Incidence marked private.
       @param workDays List of workDays
     */
-    void drawAgendaDayBox(QPainter &p, const KCalendarCore::Event::List &eventList, const QDate &qd,
-                          bool expandable, const QTime &fromTime, const QTime &toTime,
-                          const QRect &box, bool includeDescription, bool excludeTime,
-                          bool excludeConfidential, bool excludePrivate,
-                          const QList<QDate> &workDays);
+    void drawAgendaDayBox(QPainter &p, const KCalendarCore::Event::List &eventList, const QDate &qd, bool expandable, const QTime &fromTime, const QTime &toTime, const QRect &box, bool includeDescription, bool excludeTime, bool excludeConfidential, bool excludePrivate, const QList<QDate> &workDays);
 
-    void drawAgendaItem(PrintCellItem *item, QPainter &p, const QDateTime &startPrintDate,
-                        const QDateTime &endPrintDate, float minlen, const QRect &box,
-                        bool includeDescription, bool excludeTime);
+    void drawAgendaItem(PrintCellItem *item, QPainter &p, const QDateTime &startPrintDate, const QDateTime &endPrintDate, float minlen, const QRect &box, bool includeDescription, bool excludeTime);
 
     /**
       Draw the box containing a list of all events of the given day (with their times,
@@ -397,10 +382,7 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawDayBox(QPainter &p, const QDate &qd, const QTime &fromTime, const QTime &toTime,
-                    const QRect &box, bool fullDate = false, bool printRecurDaily = true,
-                    bool printRecurWeekly = true, bool singleLineLimit = true,
-                    bool showNoteLines = false, bool includeDescription = false,
+    void drawDayBox(QPainter &p, const QDate &qd, const QTime &fromTime, const QTime &toTime, const QRect &box, bool fullDate = false, bool printRecurDaily = true, bool printRecurWeekly = true, bool singleLineLimit = true, bool showNoteLines = false, bool includeDescription = false,
                     bool excludeDescription = true, bool excludePrivate = true);
     /**
       Draw the week (filofax) table of the week containing the date qd. The first
@@ -418,9 +400,7 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawWeek(QPainter &p, const QDate &qd, const QTime &fromTime, const QTime &toTime,
-                  const QRect &box, bool singleLineLimit, bool showNoteLines,
-                  bool includeDescription, bool excludeConfidential, bool excludePrivate);
+    void drawWeek(QPainter &p, const QDate &qd, const QTime &fromTime, const QTime &toTime, const QRect &box, bool singleLineLimit, bool showNoteLines, bool includeDescription, bool excludeConfidential, bool excludePrivate);
     /**
       Draw the (filofax) table for a bunch of days, using drawDayBox.
       @param p QPainter of the printout
@@ -435,9 +415,7 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawDays(QPainter &p, const QDate &start, const QDate &end, const QTime &fromTime,
-                  const QTime &toTime, const QRect &box, bool singleLineLimit, bool showNoteLines,
-                  bool includeDescription, bool excludeConfidential, bool excludePrivate);
+    void drawDays(QPainter &p, const QDate &start, const QDate &end, const QTime &fromTime, const QTime &toTime, const QRect &box, bool singleLineLimit, bool showNoteLines, bool includeDescription, bool excludeConfidential, bool excludePrivate);
     /**
       Draw the timetable view of the given time range from fromDate to toDate.
       On the left side the time scale is printed (using drawTimeLine), then each
@@ -458,10 +436,7 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawTimeTable(QPainter &p, const QDate &fromDate, const QDate &toDate, bool expandable,
-                       const QTime &fromTime, const QTime &toTime, const QRect &box,
-                       bool includeDescription, bool excludeTime, bool excludeConfidential,
-                       bool excludePrivate);
+    void drawTimeTable(QPainter &p, const QDate &fromDate, const QDate &toDate, bool expandable, const QTime &fromTime, const QTime &toTime, const QRect &box, bool includeDescription, bool excludeTime, bool excludeConfidential, bool excludePrivate);
 
     /**
       Draw the month table of the month containing the date qd. Each day gets one
@@ -483,10 +458,7 @@ public:
       @param excludePrivate Whether to exclude Incidence marked private.
       @param box coordinates of the month.
     */
-    void drawMonthTable(QPainter &p, const QDate &qd, const QTime &fromTime, const QTime &toTime,
-                        bool weeknumbers, bool recurDaily, bool recurWeekly, bool singleLineLimit,
-                        bool showNoteLines, bool includeDescription, bool excludeConfidential,
-                        bool excludePrivate, const QRect &box);
+    void drawMonthTable(QPainter &p, const QDate &qd, const QTime &fromTime, const QTime &toTime, bool weeknumbers, bool recurDaily, bool recurWeekly, bool singleLineLimit, bool showNoteLines, bool includeDescription, bool excludeConfidential, bool excludePrivate, const QRect &box);
     /**
       Draw a vertical representation of the month containing the date dt. Each
       day gets one line.
@@ -504,9 +476,7 @@ public:
       @param excludeConfidential Whether to exclude Incidence marked confidential.
       @param excludePrivate Whether to exclude Incidence marked private.
     */
-    void drawMonth(QPainter &p, const QDate &dt, const QRect &box, int maxdays = -1,
-                   int subDailyFlags = TimeBoxes, int holidaysFlags = Text,
-                   bool excludeConfidential = false, bool excludePrivate = false);
+    void drawMonth(QPainter &p, const QDate &dt, const QRect &box, int maxdays = -1, int subDailyFlags = TimeBoxes, int holidaysFlags = Text, bool excludeConfidential = false, bool excludePrivate = false);
 
     /**
       Internal class representing the start of a todo.
@@ -549,12 +519,8 @@ public:
       @param r Internal (used when printing sub-to-dos to give information
       about its parent)
     */
-    void drawTodo(int &count, const KCalendarCore::Todo::Ptr &todo, QPainter &p,
-                  KCalendarCore::TodoSortField sortField, KCalendarCore::SortDirection sortDir,
-                  bool connectSubTodos, bool strikeoutCompleted, bool desc, int posPriority,
-                  int posSummary, int posDueDt, int posPercentComplete, int level, int x, int &y,
-                  int width, int pageHeight, const KCalendarCore::Todo::List &todoList,
-                  TodoParentStart *r, bool excludeConfidential, bool excludePrivate);
+    void drawTodo(int &count, const KCalendarCore::Todo::Ptr &todo, QPainter &p, KCalendarCore::TodoSortField sortField, KCalendarCore::SortDirection sortDir, bool connectSubTodos, bool strikeoutCompleted, bool desc, int posPriority, int posSummary, int posDueDt, int posPercentComplete, int level,
+                  int x, int &y, int width, int pageHeight, const KCalendarCore::Todo::List &todoList, TodoParentStart *r, bool excludeConfidential, bool excludePrivate);
 
     /**
       Draws single journal item.
@@ -566,8 +532,7 @@ public:
       @param pageHeight Total height allowed for the list on a page. If an item
                    would be below that line, a new page is started.
     */
-    void drawJournal(const KCalendarCore::Journal::Ptr &journal, QPainter &p, int x, int &y, int width,
-                     int pageHeight);
+    void drawJournal(const KCalendarCore::Journal::Ptr &journal, QPainter &p, int x, int &y, int width, int pageHeight);
     /**
       Draws text lines splitting on page boundaries.
       @param p QPainter of the printout
@@ -577,11 +542,9 @@ public:
       @param pageHeight size of the page. A new page is started when the
              text reaches the end of the page.
     */
-    void drawTextLines(QPainter &p, const QString &entry, int x, int &y, int width, int pageHeight,
-                       bool richTextEntry);
+    void drawTextLines(QPainter &p, const QString &entry, int x, int &y, int width, int pageHeight, bool richTextEntry);
 
-    void drawSplitHeaderRight(QPainter &p, const QDate &fd, const QDate &td, const QDate &cd,
-                              int width, int height);
+    void drawSplitHeaderRight(QPainter &p, const QDate &fd, const QDate &td, const QDate &cd, int width, int height);
 
     /**
       Draws dotted lines for notes in a box.
@@ -595,13 +558,9 @@ protected:
     QTime dayStart() const;
     QColor categoryBgColor(const KCalendarCore::Incidence::Ptr &incidence) const;
 
-    void drawIncidence(QPainter &p, const QRect &dayBox, const QString &time,
-                       const QString &summary, const QString &description, int &textY,
-                       bool singleLineLimit, bool includeDescription, bool richDescription);
+    void drawIncidence(QPainter &p, const QRect &dayBox, const QString &time, const QString &summary, const QString &description, int &textY, bool singleLineLimit, bool includeDescription, bool richDescription);
     QString toPlainText(const QString &htmlText);
-    void drawTodoLines(QPainter &p, const QString &entry, int x, int &y, int width, int pageHeight,
-                       bool richTextEntry, QList<TodoParentStart *> &startPoints,
-                       bool connectSubTodos);
+    void drawTodoLines(QPainter &p, const QString &entry, int x, int &y, int width, int pageHeight, bool richTextEntry, QList<TodoParentStart *> &startPoints, bool connectSubTodos);
 
 protected:
     bool mUseColors;
