@@ -23,59 +23,39 @@
 */
 
 #include "utils.h"
+#include "calendarsupport_debug.h"
 #include "kcalprefs.h"
 
-#include <Collection>
-#include <CollectionDialog>
-#include <EntityDisplayAttribute>
-#include <EntityTreeModel>
-#include <Item>
-
 #include <AkonadiCore/AgentInstance>
 #include <AkonadiCore/AgentManager>
 #include <AkonadiCore/EntityDisplayAttribute>
+#include <AkonadiCore/EntityTreeModel>
+
+#include <AkonadiWidgets/CollectionDialog>
+
+#include <Akonadi/Calendar/BlockAlarmsAttribute>
 #include <Akonadi/Calendar/ETMCalendar>
-#include <Akonadi/Calendar/PublishDialog>
-#include <akonadi/calendar/calendarsettings.h>
 
 #include <KHolidays/HolidayRegion>
 
 #include <KCalendarCore/CalFilter>
-#include <KCalendarCore/Event>
-#include <KCalendarCore/FreeBusy>
-#include <KCalendarCore/Incidence>
-#include <KCalendarCore/Journal>
-#include <KCalendarCore/MemoryCalendar>
-#include <KCalendarCore/Todo>
-#include <KCalendarCore/ICalFormat>
 #include <KCalendarCore/FileStorage>
+#include <KCalendarCore/FreeBusy>
+#include <KCalendarCore/MemoryCalendar>
 
 #include <KCalUtils/DndFactory>
 #include <KCalUtils/ICalDrag>
 #include <KCalUtils/VCalDrag>
 
-#include <KMessageBox>
-#include <KIO/FileCopyJob>
 #include <KLocalizedString>
 
 #include <QApplication>
-#include <QUrl>
-#include <QAbstractItemModel>
 #include <QDrag>
+#include <QFile>
 #include <QMimeData>
-#include <QModelIndex>
 #include <QPointer>
-#include <QFileDialog>
-#include <QUrlQuery>
-#include <QRegularExpression>
-#include <QTimeZone>
 #include <QStyle>
-
-#include "calendarsupport_debug.h"
-
-using namespace CalendarSupport;
-using namespace KHolidays;
-using namespace KCalendarCore;
+#include <QUrlQuery>
 
 KCalendarCore::Incidence::Ptr CalendarSupport::incidence(const Akonadi::Item &item)
 {
@@ -226,9 +206,11 @@ QMimeData *CalendarSupport::createMimeData(const Akonadi::Item::List &items)
 
     mimeData->setUrls(urls);
 
-    KCalUtils::ICalDrag::populateMimeData(mimeData.get(), cal);
-
-    return mimeData.release();
+    if (KCalUtils::ICalDrag::populateMimeData(mimeData.get(), cal)) {
+        return mimeData.release();
+    } else {
+        return nullptr;
+    }
 }
 
 QMimeData *CalendarSupport::createMimeData(const Akonadi::Item &item)
@@ -303,8 +285,7 @@ Akonadi::Item::List CalendarSupport::applyCalFilter(const Akonadi::Item::List &i
     return items;
 }
 
-bool CalendarSupport::isValidIncidenceItemUrl(const QUrl &url,
-                                              const QStringList &supportedMimeTypes)
+bool CalendarSupport::isValidIncidenceItemUrl(const QUrl &url, const QStringList &supportedMimeTypes)
 {
     if (!url.isValid()) {
         return false;
@@ -413,12 +394,12 @@ KCalendarCore::Incidence::List CalendarSupport::incidences(const QMimeData *mime
     return incidences;
 }
 
-Akonadi::Collection CalendarSupport::selectCollection(QWidget *parent, int &dialogCode,
-                                                      const QStringList &mimeTypes,
-                                                      const Akonadi::Collection &defCollection)
+Akonadi::Collection CalendarSupport::selectCollection(
+    QWidget *parent, int &dialogCode, const QStringList &mimeTypes,
+    const Akonadi::Collection &defCollection)
 {
     QPointer<Akonadi::CollectionDialog> dlg(new Akonadi::CollectionDialog(parent));
-    dlg->setWindowTitle(i18n("Select Calendar"));
+    dlg->setWindowTitle(i18nc("@title:window", "Select Calendar"));
     dlg->setDescription(i18n("Select the calendar where this item will be stored."));
     dlg->changeCollectionDialogOptions(Akonadi::CollectionDialog::KeepTreeExpanded);
     qCDebug(CALENDARSUPPORT_LOG) << "selecting collections with mimeType in " << mimeTypes;
@@ -475,8 +456,8 @@ Akonadi::Collection::List CalendarSupport::collectionsFromModel(const QAbstractI
 }
 
 Akonadi::Item::List CalendarSupport::itemsFromModel(const QAbstractItemModel *model,
-                                                    const QModelIndex &parentIndex, int start,
-                                                    int end)
+                                                    const QModelIndex &parentIndex,
+                                                    int start, int end)
 {
     const int endRow = end >= 0 ? end : model->rowCount(parentIndex) - 1;
     Akonadi::Item::List items;
@@ -577,8 +558,7 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
 
         if (!ownerStr.isEmpty()) {
             if (!ownerStr.compare(QLatin1String("INBOX"), Qt::CaseInsensitive)) {
-                return i18nc("%1 is folder contents",
-                             "My Kolab %1", typeStr);
+                return i18nc("%1 is folder contents", "My Kolab %1", typeStr);
             } else if (!ownerStr.compare(QLatin1String("SHARED"), Qt::CaseInsensitive) ||
                        !ownerStr.compare(QLatin1String("CALENDAR"), Qt::CaseInsensitive) ||
                        !ownerStr.compare(QLatin1String("RESOURCES"), Qt::CaseInsensitive)) {
@@ -655,7 +635,7 @@ QString CalendarSupport::displayName(Akonadi::ETMCalendar *calendar, const Akona
 
     if (!dName.isEmpty()) {
         return fullCollection.name().startsWith(QLatin1String("akonadi_")) ? i18n("My %1",
-                                                                                   dName) : dName;
+                                                                                  dName) : dName;
     } else if (!fullCollection.name().isEmpty()) {
         return fullCollection.name();
     } else {
@@ -678,21 +658,41 @@ QString CalendarSupport::toolTipString(const Akonadi::Collection &coll, bool ric
     if (displayName.isEmpty()) {
         displayName = coll.name();
     }
+    if (coll.id() == CalendarSupport::KCalPrefs::instance()->defaultCalendarId()) {
+        displayName = i18nc("this is the default calendar", "%1 (Default Calendar)", displayName);
+    }
     str += QLatin1String("<b>") + displayName + QLatin1String("</b>");
     str += QLatin1String("<hr>");
 
     // Calendar Type
     QString calendarType;
     if (!coll.isVirtual()) {
-        const Akonadi::AgentInstance instance =
-            Akonadi::AgentManager::self()->instance(coll.resource());
+        const Akonadi::AgentInstance instance
+            = Akonadi::AgentManager::self()->instance(coll.resource());
         calendarType = instance.type().name();
     } else {
-        calendarType = i18nc("unknown calendar type", "unknown");
+        calendarType = i18nc("a virtual folder type", "Virtual");
     }
-    str += QLatin1String("<i>") + i18n("Calendar type:") + QLatin1String("</i>");
+    str += QLatin1String("<i>") + i18n("Folder type:") + QLatin1String("</i>");
     str += QLatin1String("&nbsp;") + calendarType;
 
+    // Content Type
+    QStringList mimeTypes = coll.contentMimeTypes();
+    mimeTypes.removeAll(QLatin1String("inode/directory"));
+    QString mimeTypeStr;
+    if (!mimeTypes.isEmpty()) {
+        mimeTypeStr = QLocale().createSeparatedList(
+                          mimeTypes.
+                          replaceInStrings(
+                              QLatin1String("application/x-vnd.akonadi.calendar."), QString()));
+    } else {
+        mimeTypeStr = i18nc("collection has no mimetypes to show the user", "none");
+    }
+    str += QLatin1String("<br>");
+    str += QLatin1String("<i>") + i18n("Content type:") + QLatin1String("</i>");
+    str += QLatin1String("&nbsp;") + mimeTypeStr;
+    str += QLatin1String("</br>");
+
     // Read only?
     bool isReadOnly = !(coll.rights() & Akonadi::Collection::CanChangeItem);
     str += QLatin1String("<br>");
@@ -705,9 +705,36 @@ QString CalendarSupport::toolTipString(const Akonadi::Collection &coll, bool ric
     }
     str += QLatin1String("</br>");
 
+    // Blocking reminders?
+    QStringList blockList;
+    if (coll.hasAttribute<Akonadi::BlockAlarmsAttribute>()) {
+        if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isEverythingBlocked()) {
+            blockList << i18nc("blocking all reminders for this calendar", "all");
+        } else {
+            if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isAlarmTypeBlocked(KCalendarCore::Alarm::Audio)) {
+                blockList << i18nc("blocking audio reminders for this calendar", "audio");
+            } else if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isAlarmTypeBlocked(KCalendarCore::Alarm::Display)) {
+                blockList << i18nc("blocking display pop-up dialog reminders for this calendar", "display");
+            } else if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isAlarmTypeBlocked(KCalendarCore::Alarm::Email)) {
+                blockList << i18nc("blocking email reminders for this calendar", "email");
+            } else if (coll.attribute<Akonadi::BlockAlarmsAttribute>()->isAlarmTypeBlocked(KCalendarCore::Alarm::Procedure)) {
+                blockList << i18nc("blocking run a command reminders for this calendar", "procedure");
+            } else {
+                blockList << i18nc("blocking unknown type reminders for this calendar", "other");
+            }
+        }
+    } else {
+        blockList << i18nc("not blocking any reminder types for this calendar", "none");
+    }
+    str += QLatin1String("<br>");
+    str += QLatin1String("<i>") + i18n("Blocked Reminders:") + QLatin1String("</i>");
+    str += QLatin1String("&nbsp;");
+    str += QLocale().createSeparatedList(blockList);
+    str += QLatin1String("</br>");
+
     str += QLatin1String("</qt>");
     return str;
- }
+}
 
 QString CalendarSupport::subMimeTypeForIncidence(const KCalendarCore::Incidence::Ptr &incidence)
 {
@@ -736,8 +763,8 @@ QList<QDate> CalendarSupport::workDays(const QDate &startDate, const QDate &endD
                 const KHolidays::Holiday::List list = region.holidays(startDate, endDate);
                 const int listCount(list.count());
                 for (int i = 0; i < listCount; ++i) {
-                    const Holiday &h = list.at(i);
-                    if (h.dayType() == Holiday::NonWorkday) {
+                    const KHolidays::Holiday &h = list.at(i);
+                    if (h.dayType() == KHolidays::Holiday::NonWorkday) {
                         result.removeAll(h.observedStartDate());
                     }
                 }
@@ -757,7 +784,7 @@ QStringList CalendarSupport::holiday(const QDate &date)
     for (const QString &regionStr : holidays) {
         KHolidays::HolidayRegion region(regionStr);
         if (region.isValid()) {
-            const Holiday::List list = region.holidays(date);
+            const KHolidays::Holiday::List list = region.holidays(date);
             const int listCount = list.count();
             for (int i = 0; i < listCount; ++i) {
                 // don't add duplicates.
@@ -809,8 +836,7 @@ QStringList CalendarSupport::categories(const KCalendarCore::Incidence::List &in
     return cats;
 }
 
-bool CalendarSupport::mergeCalendar(const QString &srcFilename,
-                                    const KCalendarCore::Calendar::Ptr &destCalendar)
+bool CalendarSupport::mergeCalendar(const QString &srcFilename, const KCalendarCore::Calendar::Ptr &destCalendar)
 {
     if (srcFilename.isEmpty()) {
         qCCritical(CALENDARSUPPORT_LOG) << "Empty filename.";
@@ -831,7 +857,8 @@ bool CalendarSupport::mergeCalendar(const QString &srcFilename,
     return loadedSuccesfully;
 }
 
-void CalendarSupport::createAlarmReminder(const Alarm::Ptr &alarm, KCalendarCore::IncidenceBase::IncidenceType type)
+void CalendarSupport::createAlarmReminder(const KCalendarCore::Alarm::Ptr &alarm,
+                                          KCalendarCore::IncidenceBase::IncidenceType type)
 {
     int duration; // in secs
     switch (CalendarSupport::KCalPrefs::instance()->mReminderTimeUnits) {
